@@ -14,7 +14,7 @@ import pandas.util._test_decorators as td
 from pandas.core.dtypes.common import is_bool, is_list_like, is_scalar
 
 import pandas as pd
-from pandas import DataFrame, Series, date_range
+from pandas import DataFrame, Series, compat, date_range
 from pandas.core.computation import pytables
 from pandas.core.computation.check import _NUMEXPR_VERSION
 from pandas.core.computation.engines import NumExprClobberingError, _engines
@@ -1267,7 +1267,10 @@ class TestOperationsNumExprPandas:
         msg = "left hand side of an assignment must be a single name"
         with pytest.raises(SyntaxError, match=msg):
             df.eval("d,c = a + b")
-        msg = "can't assign to function call"
+        if compat.PY38:
+            msg = "cannot assign to function call"
+        else:
+            msg = "can't assign to function call"
         with pytest.raises(SyntaxError, match=msg):
             df.eval('Timestamp("20131001") = a + b')
 
@@ -1967,6 +1970,26 @@ def test_bool_ops_fails_on_scalars(lhs, cmp, rhs, engine, parser):
             pd.eval(ex, engine=engine, parser=parser)
 
 
+@pytest.mark.parametrize(
+    "other",
+    [
+        "'x'",
+        pytest.param(
+            "...", marks=pytest.mark.xfail(not compat.PY38, reason="GH-28116")
+        ),
+    ],
+)
+def test_equals_various(other):
+    df = DataFrame({"A": ["a", "b", "c"]})
+    result = df.eval("A == {}".format(other))
+    expected = Series([False, False, False], name="A")
+    if _USE_NUMEXPR:
+        # https://github.com/pandas-dev/pandas/issues/10239
+        # lose name with numexpr engine. Remove when that's fixed.
+        expected.name = None
+    tm.assert_series_equal(result, expected)
+
+
 def test_inf(engine, parser):
     s = "inf + 1"
     expected = np.inf
