@@ -1,34 +1,27 @@
-# coding=utf-8
-
+import numpy as np
 import pytest
 
-import numpy as np
-from pandas import (offsets, Series, notnull,
-                    isnull, date_range, Timestamp)
-
+from pandas import Series, Timestamp, date_range, isna, notna, offsets
 import pandas.util.testing as tm
 
-from .common import TestData
-
-
-class TestSeriesAsof(TestData):
 
+class TestSeriesAsof:
     def test_basic(self):
 
         # array or list or dates
         N = 50
-        rng = date_range('1/1/1990', periods=N, freq='53s')
+        rng = date_range("1/1/1990", periods=N, freq="53s")
         ts = Series(np.random.randn(N), index=rng)
         ts[15:30] = np.nan
-        dates = date_range('1/1/1990', periods=N * 3, freq='25s')
+        dates = date_range("1/1/1990", periods=N * 3, freq="25s")
 
         result = ts.asof(dates)
-        assert notnull(result).all()
+        assert notna(result).all()
         lb = ts.index[14]
         ub = ts.index[30]
 
         result = ts.asof(list(dates))
-        assert notnull(result).all()
+        assert notna(result).all()
         lb = ts.index[14]
         ub = ts.index[30]
 
@@ -42,7 +35,7 @@ class TestSeriesAsof(TestData):
     def test_scalar(self):
 
         N = 30
-        rng = date_range('1/1/1990', periods=N, freq='53s')
+        rng = date_range("1/1/1990", periods=N, freq="53s")
         ts = Series(np.arange(N), index=rng)
         ts[5:10] = np.NaN
         ts[15:20] = np.NaN
@@ -67,47 +60,54 @@ class TestSeriesAsof(TestData):
 
     def test_with_nan(self):
         # basic asof test
-        rng = date_range('1/1/2000', '1/2/2000', freq='4h')
+        rng = date_range("1/1/2000", "1/2/2000", freq="4h")
         s = Series(np.arange(len(rng)), index=rng)
-        r = s.resample('2h').mean()
+        r = s.resample("2h").mean()
 
         result = r.asof(r.index)
-        expected = Series([0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6.],
-                          index=date_range('1/1/2000', '1/2/2000', freq='2h'))
+        expected = Series(
+            [0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6.0],
+            index=date_range("1/1/2000", "1/2/2000", freq="2h"),
+        )
         tm.assert_series_equal(result, expected)
 
         r.iloc[3:5] = np.nan
         result = r.asof(r.index)
-        expected = Series([0, 0, 1, 1, 1, 1, 3, 3, 4, 4, 5, 5, 6.],
-                          index=date_range('1/1/2000', '1/2/2000', freq='2h'))
+        expected = Series(
+            [0, 0, 1, 1, 1, 1, 3, 3, 4, 4, 5, 5, 6.0],
+            index=date_range("1/1/2000", "1/2/2000", freq="2h"),
+        )
         tm.assert_series_equal(result, expected)
 
         r.iloc[-3:] = np.nan
         result = r.asof(r.index)
-        expected = Series([0, 0, 1, 1, 1, 1, 3, 3, 4, 4, 4, 4, 4.],
-                          index=date_range('1/1/2000', '1/2/2000', freq='2h'))
+        expected = Series(
+            [0, 0, 1, 1, 1, 1, 3, 3, 4, 4, 4, 4, 4.0],
+            index=date_range("1/1/2000", "1/2/2000", freq="2h"),
+        )
         tm.assert_series_equal(result, expected)
 
     def test_periodindex(self):
         from pandas import period_range, PeriodIndex
+
         # array or list or dates
         N = 50
-        rng = period_range('1/1/1990', periods=N, freq='H')
+        rng = period_range("1/1/1990", periods=N, freq="H")
         ts = Series(np.random.randn(N), index=rng)
         ts[15:30] = np.nan
-        dates = date_range('1/1/1990', periods=N * 3, freq='37min')
+        dates = date_range("1/1/1990", periods=N * 3, freq="37min")
 
         result = ts.asof(dates)
-        assert notnull(result).all()
+        assert notna(result).all()
         lb = ts.index[14]
         ub = ts.index[30]
 
         result = ts.asof(list(dates))
-        assert notnull(result).all()
+        assert notna(result).all()
         lb = ts.index[14]
         ub = ts.index[30]
 
-        pix = PeriodIndex(result.index.values, freq='H')
+        pix = PeriodIndex(result.index.values, freq="H")
         mask = (pix >= lb) & (pix < ub)
         rs = result[mask]
         assert (rs == ts[lb]).all()
@@ -130,14 +130,14 @@ class TestSeriesAsof(TestData):
 
         # no as of value
         d = ts.index[0].to_timestamp() - offsets.BDay()
-        assert isnull(ts.asof(d))
+        assert isna(ts.asof(d))
 
     def test_errors(self):
 
-        s = Series([1, 2, 3],
-                   index=[Timestamp('20130101'),
-                          Timestamp('20130103'),
-                          Timestamp('20130102')])
+        s = Series(
+            [1, 2, 3],
+            index=[Timestamp("20130101"), Timestamp("20130103"), Timestamp("20130102")],
+        )
 
         # non-monotonic
         assert not s.index.is_monotonic
@@ -146,10 +146,10 @@ class TestSeriesAsof(TestData):
 
         # subset with Series
         N = 10
-        rng = date_range('1/1/1990', periods=N, freq='53s')
+        rng = date_range("1/1/1990", periods=N, freq="53s")
         s = Series(np.random.randn(N), index=rng)
         with pytest.raises(ValueError):
-            s.asof(s.index[0], subset='foo')
+            s.asof(s.index[0], subset="foo")
 
     def test_all_nans(self):
         # GH 15713
@@ -160,19 +160,19 @@ class TestSeriesAsof(TestData):
 
         # testing non-default indexes
         N = 50
-        rng = date_range('1/1/1990', periods=N, freq='53s')
+        rng = date_range("1/1/1990", periods=N, freq="53s")
 
-        dates = date_range('1/1/1990', periods=N * 3, freq='25s')
+        dates = date_range("1/1/1990", periods=N * 3, freq="25s")
         result = Series(np.nan, index=rng).asof(dates)
         expected = Series(np.nan, index=dates)
         tm.assert_series_equal(result, expected)
 
         # testing scalar input
-        date = date_range('1/1/1990', periods=N * 3, freq='25s')[0]
+        date = date_range("1/1/1990", periods=N * 3, freq="25s")[0]
         result = Series(np.nan, index=rng).asof(date)
-        assert isnull(result)
+        assert isna(result)
 
         # test name is propagated
-        result = Series(np.nan, index=[1, 2, 3, 4], name='test').asof([4, 5])
-        expected = Series(np.nan, index=[4, 5], name='test')
+        result = Series(np.nan, index=[1, 2, 3, 4], name="test").asof([4, 5])
+        expected = Series(np.nan, index=[4, 5], name="test")
         tm.assert_series_equal(result, expected)
